@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Recode Library; see the file `COPYING.LIB'.
-   If not, write to the Free Software Foundation, Inc., 59 Temple Place -
-   Suite 330, Boston, MA 02111-1307, USA.  */
+   If not, see <https://www.gnu.org/licenses/>.
+*/
 
 /* Extended definitions, for externally written steps.  */
 
@@ -355,6 +355,9 @@ struct recode_request
        selected so to approximate these boxes.  */
     bool ascii_graphics : 1;
 
+    /* Use iconv if possible. */
+    bool prefer_iconv : 1;
+
     /* Array stating the sequence of conversions.  */
     RECODE_STEP sequence_array;
     size_t sequence_allocated;
